@@ -36,7 +36,7 @@
 
 /* These constants aren't available in older SDKs */
 #ifndef AUDCLNT_STREAMFLAGS_RATEADJUST
-#define AUDCLNT_STREAMFLAGS_RATEADJUST  0x00100000
+#define AUDCLNT_STREAMFLAGS_RATEADJUST 0x00100000
 #endif
 #ifndef AUDCLNT_STREAMFLAGS_SRC_DEFAULT_QUALITY
 #define AUDCLNT_STREAMFLAGS_SRC_DEFAULT_QUALITY 0x08000000
@@ -46,17 +46,16 @@
 #endif
 
 /* Some GUIDs we need to know without linking to libraries that aren't available before Vista. */
-static const IID SDL_IID_IAudioRenderClient = { 0xf294acfc, 0x3146, 0x4483,{ 0xa7, 0xbf, 0xad, 0xdc, 0xa7, 0xc2, 0x60, 0xe2 } };
-static const IID SDL_IID_IAudioCaptureClient = { 0xc8adbd64, 0xe71e, 0x48a0,{ 0xa4, 0xde, 0x18, 0x5c, 0x39, 0x5c, 0xd3, 0x17 } };
+static const IID SDL_IID_IAudioRenderClient = { 0xf294acfc, 0x3146, 0x4483, { 0xa7, 0xbf, 0xad, 0xdc, 0xa7, 0xc2, 0x60, 0xe2 } };
+static const IID SDL_IID_IAudioCaptureClient = { 0xc8adbd64, 0xe71e, 0x48a0, { 0xa4, 0xde, 0x18, 0x5c, 0x39, 0x5c, 0xd3, 0x17 } };
 
-static void
-WASAPI_DetectDevices(void)
+
+static void WASAPI_DetectDevices(void)
 {
     WASAPI_EnumerateEndpoints();
 }
 
-static SDL_INLINE SDL_bool
-WasapiFailed(_THIS, const HRESULT err)
+static SDL_INLINE SDL_bool WasapiFailed(_THIS, const HRESULT err)
 {
     if (err == S_OK) {
         return SDL_FALSE;
@@ -73,39 +72,38 @@ WasapiFailed(_THIS, const HRESULT err)
     return SDL_TRUE;
 }
 
-static int
-UpdateAudioStream(_THIS, const SDL_AudioSpec *oldspec)
+static int UpdateAudioStream(_THIS, const SDL_AudioSpec *oldspec)
 {
     /* Since WASAPI requires us to handle all audio conversion, and our
        device format might have changed, we might have to add/remove/change
        the audio stream that the higher level uses to convert data, so
        SDL keeps firing the callback as if nothing happened here. */
 
-    if ( (this->callbackspec.channels == this->spec.channels) &&
-         (this->callbackspec.format == this->spec.format) &&
-         (this->callbackspec.freq == this->spec.freq) &&
-         (this->callbackspec.samples == this->spec.samples) ) {
+    if ((this->callbackspec.channels == this->spec.channels) &&
+        (this->callbackspec.format == this->spec.format) &&
+        (this->callbackspec.freq == this->spec.freq) &&
+        (this->callbackspec.samples == this->spec.samples)) {
         /* no need to buffer/convert in an AudioStream! */
         SDL_FreeAudioStream(this->stream);
         this->stream = NULL;
-    } else if ( (oldspec->channels == this->spec.channels) &&
-         (oldspec->format == this->spec.format) &&
-         (oldspec->freq == this->spec.freq) ) {
+    } else if ((oldspec->channels == this->spec.channels) &&
+               (oldspec->format == this->spec.format) &&
+               (oldspec->freq == this->spec.freq)) {
         /* The existing audio stream is okay to keep using. */
     } else {
         /* replace the audiostream for new format */
         SDL_FreeAudioStream(this->stream);
         if (this->iscapture) {
             this->stream = SDL_NewAudioStream(this->spec.format,
-                                this->spec.channels, this->spec.freq,
-                                this->callbackspec.format,
-                                this->callbackspec.channels,
-                                this->callbackspec.freq);
+                                              this->spec.channels, this->spec.freq,
+                                              this->callbackspec.format,
+                                              this->callbackspec.channels,
+                                              this->callbackspec.freq);
         } else {
             this->stream = SDL_NewAudioStream(this->callbackspec.format,
-                                this->callbackspec.channels,
-                                this->callbackspec.freq, this->spec.format,
-                                this->spec.channels, this->spec.freq);
+                                              this->callbackspec.channels,
+                                              this->callbackspec.freq, this->spec.format,
+                                              this->spec.channels, this->spec.freq);
         }
 
         if (!this->stream) {
@@ -115,7 +113,7 @@ UpdateAudioStream(_THIS, const SDL_AudioSpec *oldspec)
 
     /* make sure our scratch buffer can cover the new device spec. */
     if (this->spec.size > this->work_buffer_len) {
-        Uint8 *ptr = (Uint8 *) SDL_realloc(this->work_buffer, this->spec.size);
+        Uint8 *ptr = (Uint8 *)SDL_realloc(this->work_buffer, this->spec.size);
         if (ptr == NULL) {
             return SDL_OutOfMemory();
         }
@@ -126,16 +124,14 @@ UpdateAudioStream(_THIS, const SDL_AudioSpec *oldspec)
     return 0;
 }
 
-
 static void ReleaseWasapiDevice(_THIS);
 
-static SDL_bool
-RecoverWasapiDevice(_THIS)
+static SDL_bool RecoverWasapiDevice(_THIS)
 {
-    ReleaseWasapiDevice(this);  /* dump the lost device's handles. */
+    ReleaseWasapiDevice(this); /* dump the lost device's handles. */
 
     if (this->hidden->default_device_generation) {
-        this->hidden->default_device_generation = SDL_AtomicGet(this->iscapture ?  &SDL_IMMDevice_DefaultCaptureGeneration : &SDL_IMMDevice_DefaultPlaybackGeneration);
+        this->hidden->default_device_generation = SDL_AtomicGet(this->iscapture ? &SDL_IMMDevice_DefaultCaptureGeneration : &SDL_IMMDevice_DefaultPlaybackGeneration);
     }
 
     /* this can fail for lots of reasons, but the most likely is we had a
@@ -150,26 +146,25 @@ RecoverWasapiDevice(_THIS)
 
     this->hidden->device_lost = SDL_FALSE;
 
-    return SDL_TRUE;  /* okay, carry on with new device details! */
+    return SDL_TRUE; /* okay, carry on with new device details! */
 }
 
-static SDL_bool
-RecoverWasapiIfLost(_THIS)
+static SDL_bool RecoverWasapiIfLost(_THIS)
 {
     const int generation = this->hidden->default_device_generation;
     SDL_bool lost = this->hidden->device_lost;
 
     if (!SDL_AtomicGet(&this->enabled)) {
-        return SDL_FALSE;  /* already failed. */
+        return SDL_FALSE; /* already failed. */
     }
 
     if (!this->hidden->client) {
-        return SDL_TRUE;  /* still waiting for activation. */
+        return SDL_TRUE; /* still waiting for activation. */
     }
 
     if (!lost && (generation > 0)) { /* is a default device? */
         const int newgen = SDL_AtomicGet(this->iscapture ? &SDL_IMMDevice_DefaultCaptureGeneration : &SDL_IMMDevice_DefaultPlaybackGeneration);
-        if (generation != newgen) {  /* the desired default device was changed, jump over to it. */
+        if (generation != newgen) { /* the desired default device was changed, jump over to it. */
             lost = SDL_TRUE;
         }
     }
@@ -177,33 +172,30 @@ RecoverWasapiIfLost(_THIS)
     return lost ? RecoverWasapiDevice(this) : SDL_TRUE;
 }
 
-static Uint8 *
-WASAPI_GetDeviceBuf(_THIS)
+static Uint8 *WASAPI_GetDeviceBuf(_THIS)
 {
     /* get an endpoint buffer from WASAPI. */
     BYTE *buffer = NULL;
 
     while (RecoverWasapiIfLost(this) && this->hidden->render) {
         if (!WasapiFailed(this, IAudioRenderClient_GetBuffer(this->hidden->render, this->spec.samples, &buffer))) {
-            return (Uint8 *) buffer;
+            return (Uint8 *)buffer;
         }
         SDL_assert(buffer == NULL);
     }
 
-    return (Uint8 *) buffer;
+    return (Uint8 *)buffer;
 }
 
-static void
-WASAPI_PlayDevice(_THIS)
+static void WASAPI_PlayDevice(_THIS)
 {
-    if (this->hidden->render != NULL) {  /* definitely activated? */
+    if (this->hidden->render != NULL) { /* definitely activated? */
         /* WasapiFailed() will mark the device for reacquisition or removal elsewhere. */
         WasapiFailed(this, IAudioRenderClient_ReleaseBuffer(this->hidden->render, this->spec.samples, 0));
     }
 }
 
-static void
-WASAPI_WaitDevice(_THIS)
+static void WASAPI_WaitDevice(_THIS)
 {
     while (RecoverWasapiIfLost(this) && this->hidden->client && this->hidden->event) {
         DWORD waitResult = WaitForSingleObjectEx(this->hidden->event, 200, FALSE);
@@ -230,8 +222,7 @@ WASAPI_WaitDevice(_THIS)
     }
 }
 
-static int
-WASAPI_CaptureFromDevice(_THIS, void *buffer, int buflen)
+static int WASAPI_CaptureFromDevice(_THIS, void *buffer, int buflen)
 {
     SDL_AudioStream *stream = this->hidden->capturestream;
     const int avail = SDL_AudioStreamAvailable(stream);
@@ -263,7 +254,7 @@ WASAPI_CaptureFromDevice(_THIS, void *buffer, int buflen)
         if ((ret == AUDCLNT_S_BUFFER_EMPTY) || !frames) {
             WASAPI_WaitDevice(this);
         } else if (ret == S_OK) {
-            const int total = ((int) frames) * this->hidden->framesize;
+            const int total = ((int)frames) * this->hidden->framesize;
             const int cpy = SDL_min(buflen, total);
             const int leftover = total - cpy;
             const SDL_bool silent = (flags & AUDCLNT_BUFFERFLAGS_SILENT) ? SDL_TRUE : SDL_FALSE;
@@ -273,15 +264,15 @@ WASAPI_CaptureFromDevice(_THIS, void *buffer, int buflen)
             } else {
                 SDL_memcpy(buffer, ptr, cpy);
             }
-            
+
             if (leftover > 0) {
                 ptr += cpy;
                 if (silent) {
-                    SDL_memset(ptr, this->spec.silence, leftover);  /* I guess this is safe? */
+                    SDL_memset(ptr, this->spec.silence, leftover); /* I guess this is safe? */
                 }
 
                 if (SDL_AudioStreamPut(stream, ptr, leftover) == -1) {
-                    return -1;  /* uhoh, out of memory, etc. Kill device.  :( */
+                    return -1; /* uhoh, out of memory, etc. Kill device.  :( */
                 }
             }
 
@@ -292,36 +283,34 @@ WASAPI_CaptureFromDevice(_THIS, void *buffer, int buflen)
         }
     }
 
-    return -1;  /* unrecoverable error. */
+    return -1; /* unrecoverable error. */
 }
 
-static void
-WASAPI_FlushCapture(_THIS)
+static void WASAPI_FlushCapture(_THIS)
 {
     BYTE *ptr = NULL;
     UINT32 frames = 0;
     DWORD flags = 0;
 
     if (!this->hidden->capture) {
-        return;  /* not activated yet? */
+        return; /* not activated yet? */
     }
 
     /* just read until we stop getting packets, throwing them away. */
     while (SDL_TRUE) {
         const HRESULT ret = IAudioCaptureClient_GetBuffer(this->hidden->capture, &ptr, &frames, &flags, NULL, NULL);
         if (ret == AUDCLNT_S_BUFFER_EMPTY) {
-            break;  /* no more buffered data; we're done. */
+            break; /* no more buffered data; we're done. */
         } else if (WasapiFailed(this, ret)) {
-            break;  /* failed for some other reason, abort. */
+            break; /* failed for some other reason, abort. */
         } else if (WasapiFailed(this, IAudioCaptureClient_ReleaseBuffer(this->hidden->capture, frames))) {
-            break;  /* something broke. */
+            break; /* something broke. */
         }
     }
     SDL_AudioStreamClear(this->hidden->capturestream);
 }
 
-static void
-ReleaseWasapiDevice(_THIS)
+static void ReleaseWasapiDevice(_THIS)
 {
     if (this->hidden->client) {
         IAudioClient_Stop(this->hidden->client);
@@ -360,20 +349,17 @@ ReleaseWasapiDevice(_THIS)
     }
 }
 
-static void
-WASAPI_CloseDevice(_THIS)
+static void WASAPI_CloseDevice(_THIS)
 {
     WASAPI_UnrefDevice(this);
 }
 
-void
-WASAPI_RefDevice(_THIS)
+void WASAPI_RefDevice(_THIS)
 {
     SDL_AtomicIncRef(&this->hidden->refcount);
 }
 
-void
-WASAPI_UnrefDevice(_THIS)
+void WASAPI_UnrefDevice(_THIS)
 {
     if (!SDL_AtomicDecRef(&this->hidden->refcount)) {
         return;
@@ -385,13 +371,17 @@ WASAPI_UnrefDevice(_THIS)
        our callback thread. We do that in WASAPI_ThreadDeinit().
        (likewise for this->hidden->coinitialized). */
     ReleaseWasapiDevice(this);
+
+    if (SDL_ThreadID() == this->hidden->open_threadid) {
+        WIN_CoUninitialize();  /* if you closed from a different thread than you opened, sorry, it's a leak. We can't help you. */
+    }
+
     SDL_free(this->hidden->devid);
     SDL_free(this->hidden);
 }
 
 /* This is called once a device is activated, possibly asynchronously. */
-int
-WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
+int WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
 {
     /* !!! FIXME: we could request an exclusive mode stream, which is lower latency;
        !!!  it will write into the kernel's audio buffer directly instead of
@@ -406,7 +396,7 @@ WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
        !!!  do in any case. */
     const SDL_AudioSpec oldspec = this->spec;
     const AUDCLNT_SHAREMODE sharemode = AUDCLNT_SHAREMODE_SHARED;
-    UINT32 bufsize = 0;  /* this is in sample frames, not samples, not bytes. */
+    UINT32 bufsize = 0; /* this is in sample frames, not samples, not bytes. */
     REFERENCE_TIME default_period = 0;
     IAudioClient *client = this->hidden->client;
     IAudioRenderClient *render = NULL;
@@ -437,7 +427,7 @@ WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
     SDL_assert(waveformat != NULL);
     this->hidden->waveformat = waveformat;
 
-    this->spec.channels = (Uint8) waveformat->nChannels;
+    this->spec.channels = (Uint8)waveformat->nChannels;
 
     /* Make sure we have a valid format that we can convert to whatever WASAPI wants. */
     wasapi_format = WaveFormatToSDLFormat(waveformat);
@@ -504,10 +494,10 @@ WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
     if (this->iscapture) {
         this->hidden->capturestream = SDL_NewAudioStream(this->spec.format, this->spec.channels, this->spec.freq, this->spec.format, this->spec.channels, this->spec.freq);
         if (!this->hidden->capturestream) {
-            return -1;  /* already set SDL_Error */
+            return -1; /* already set SDL_Error */
         }
 
-        ret = IAudioClient_GetService(client, &SDL_IID_IAudioCaptureClient, (void**) &capture);
+        ret = IAudioClient_GetService(client, &SDL_IID_IAudioCaptureClient, (void **)&capture);
         if (FAILED(ret)) {
             return WIN_SetErrorFromHRESULT("WASAPI can't get capture client service", ret);
         }
@@ -519,9 +509,9 @@ WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
             return WIN_SetErrorFromHRESULT("WASAPI can't start capture", ret);
         }
 
-        WASAPI_FlushCapture(this);  /* MSDN says you should flush capture endpoint right after startup. */
+        WASAPI_FlushCapture(this); /* MSDN says you should flush capture endpoint right after startup. */
     } else {
-        ret = IAudioClient_GetService(client, &SDL_IID_IAudioRenderClient, (void**) &render);
+        ret = IAudioClient_GetService(client, &SDL_IID_IAudioRenderClient, (void **)&render);
         if (FAILED(ret)) {
             return WIN_SetErrorFromHRESULT("WASAPI can't get render client service", ret);
         }
@@ -538,26 +528,28 @@ WASAPI_PrepDevice(_THIS, const SDL_bool updatestream)
         return UpdateAudioStream(this, &oldspec);
     }
 
-    return 0;  /* good to go. */
+    return 0; /* good to go. */
 }
 
-
-static int
-WASAPI_OpenDevice(_THIS, const char *devname)
+static int WASAPI_OpenDevice(_THIS, const char *devname)
 {
-    LPCWSTR devid = (LPCWSTR) this->handle;
+    LPCWSTR devid = (LPCWSTR)this->handle;
 
     /* Initialize all variables that we clean on shutdown */
-    this->hidden = (struct SDL_PrivateAudioData *)
-        SDL_malloc((sizeof *this->hidden));
+    this->hidden = (struct SDL_PrivateAudioData *) SDL_malloc(sizeof(*this->hidden));
     if (this->hidden == NULL) {
         return SDL_OutOfMemory();
     }
     SDL_zerop(this->hidden);
 
-    WASAPI_RefDevice(this);   /* so CloseDevice() will unref to zero. */
+    WASAPI_RefDevice(this); /* so CloseDevice() will unref to zero. */
 
-    if (!devid) {  /* is default device? */
+    if (FAILED(WIN_CoInitialize())) {  /* WASAPI uses COM, we need to make sure it's initialized. You have to close the device from the same thread!! */
+        return SDL_SetError("WIN_CoInitialize failed during WASAPI device open");
+    }
+    this->hidden->open_threadid = SDL_ThreadID();  /* set this _after_ coinitialize so we don't uninit if device fails at the wrong moment. */
+
+    if (!devid) { /* is default device? */
         this->hidden->default_device_generation = SDL_AtomicGet(this->iscapture ? &SDL_IMMDevice_DefaultCaptureGeneration : &SDL_IMMDevice_DefaultPlaybackGeneration);
     } else {
         this->hidden->devid = SDL_wcsdup(devid);
@@ -567,7 +559,7 @@ WASAPI_OpenDevice(_THIS, const char *devname)
     }
 
     if (WASAPI_ActivateDevice(this, SDL_FALSE) == -1) {
-        return -1;  /* already set error. */
+        return -1; /* already set error. */
     }
 
     /* Ready, but waiting for async device activation.
@@ -581,26 +573,22 @@ WASAPI_OpenDevice(_THIS, const char *devname)
     return 0;
 }
 
-static void
-WASAPI_ThreadInit(_THIS)
+static void WASAPI_ThreadInit(_THIS)
 {
     WASAPI_PlatformThreadInit(this);
 }
 
-static void
-WASAPI_ThreadDeinit(_THIS)
+static void WASAPI_ThreadDeinit(_THIS)
 {
     WASAPI_PlatformThreadDeinit(this);
 }
 
-static void
-WASAPI_Deinitialize(void)
+static void WASAPI_Deinitialize(void)
 {
     WASAPI_PlatformDeinit();
 }
 
-static SDL_bool
-WASAPI_Init(SDL_AudioDriverImpl * impl)
+static SDL_bool WASAPI_Init(SDL_AudioDriverImpl *impl)
 {
     if (WASAPI_PlatformInit() == -1) {
         return SDL_FALSE;
@@ -622,13 +610,13 @@ WASAPI_Init(SDL_AudioDriverImpl * impl)
     impl->HasCaptureSupport = SDL_TRUE;
     impl->SupportsNonPow2Samples = SDL_TRUE;
 
-    return SDL_TRUE;   /* this audio target is available. */
+    return SDL_TRUE; /* this audio target is available. */
 }
 
 AudioBootStrap WASAPI_bootstrap = {
     "wasapi", "WASAPI", WASAPI_Init, SDL_FALSE
 };
 
-#endif  /* SDL_AUDIO_DRIVER_WASAPI */
+#endif /* SDL_AUDIO_DRIVER_WASAPI */
 
 /* vi: set ts=4 sw=4 expandtab: */
