@@ -54,51 +54,47 @@ int Android_GetDisplayDPI(_THIS, SDL_VideoDisplay *display, float *ddpi, float *
 #define Android_GLES_UnloadLibrary SDL_EGL_UnloadLibrary
 #define Android_GLES_SetSwapInterval SDL_EGL_SetSwapInterval
 #define Android_GLES_GetSwapInterval SDL_EGL_GetSwapInterval
-#define Android_GLES_DeleteContext SDL_EGL_DeleteContext
+#define Android_GLES_DeleteContext   SDL_EGL_DeleteContext
 
 /* Android driver bootstrap functions */
 
-
 /* These are filled in with real values in Android_SetScreenResolution on init (before SDL_main()) */
-int Android_SurfaceWidth           = 0;
-int Android_SurfaceHeight          = 0;
-static int Android_DeviceWidth     = 0;
-static int Android_DeviceHeight    = 0;
+int Android_SurfaceWidth = 0;
+int Android_SurfaceHeight = 0;
+static int Android_DeviceWidth = 0;
+static int Android_DeviceHeight = 0;
 static Uint32 Android_ScreenFormat = SDL_PIXELFORMAT_RGB565; /* Default SurfaceView format, in case this is queried before being filled */
-static int Android_ScreenRate      = 0;
-SDL_sem *Android_PauseSem          = NULL;
-SDL_sem *Android_ResumeSem         = NULL;
-SDL_mutex *Android_ActivityMutex   = NULL;
+static int Android_ScreenRate = 0;
+SDL_sem *Android_PauseSem = NULL;
+SDL_sem *Android_ResumeSem = NULL;
+SDL_mutex *Android_ActivityMutex = NULL;
 
-static void
-Android_SuspendScreenSaver(_THIS)
+static void Android_SuspendScreenSaver(_THIS)
 {
     Android_JNI_SuspendScreenSaver(_this->suspend_screensaver);
 }
 
-static void
-Android_DeleteDevice(SDL_VideoDevice *device)
+static void Android_DeleteDevice(SDL_VideoDevice *device)
 {
     SDL_free(device->driverdata);
     SDL_free(device);
 }
 
-static SDL_VideoDevice *
-Android_CreateDevice(void)
+static SDL_VideoDevice *Android_CreateDevice(void)
 {
     SDL_VideoDevice *device;
     SDL_VideoData *data;
     SDL_bool block_on_pause;
 
     /* Initialize all variables that we clean on shutdown */
-    device = (SDL_VideoDevice *) SDL_calloc(1, sizeof(SDL_VideoDevice));
-    if (!device) {
+    device = (SDL_VideoDevice *)SDL_calloc(1, sizeof(SDL_VideoDevice));
+    if (device == NULL) {
         SDL_OutOfMemory();
         return NULL;
     }
 
-    data = (SDL_VideoData *) SDL_calloc(1, sizeof(SDL_VideoData));
-    if (!data) {
+    data = (SDL_VideoData *)SDL_calloc(1, sizeof(SDL_VideoData));
+    if (data == NULL) {
         SDL_OutOfMemory();
         SDL_free(device);
         return NULL;
@@ -173,24 +169,22 @@ VideoBootStrap Android_bootstrap = {
     Android_CreateDevice
 };
 
-
-int
-Android_VideoInit(_THIS)
+int Android_VideoInit(_THIS)
 {
     SDL_VideoData *videodata = (SDL_VideoData *)_this->driverdata;
     int display_index;
     SDL_VideoDisplay *display;
     SDL_DisplayMode mode;
 
-    videodata->isPaused  = SDL_FALSE;
+    videodata->isPaused = SDL_FALSE;
     videodata->isPausing = SDL_FALSE;
     videodata->pauseAudio = SDL_GetHintBoolean(SDL_HINT_ANDROID_BLOCK_ON_PAUSE_PAUSEAUDIO, SDL_TRUE);
 
-    mode.format          = Android_ScreenFormat;
-    mode.w               = Android_DeviceWidth;
-    mode.h               = Android_DeviceHeight;
-    mode.refresh_rate    = Android_ScreenRate;
-    mode.driverdata      = NULL;
+    mode.format = Android_ScreenFormat;
+    mode.w = Android_DeviceWidth;
+    mode.h = Android_DeviceHeight;
+    mode.refresh_rate = Android_ScreenRate;
+    mode.driverdata = NULL;
 
     display_index = SDL_AddBasicVideoDisplay(&mode);
     if (display_index < 0) {
@@ -209,33 +203,30 @@ Android_VideoInit(_THIS)
     return 0;
 }
 
-void
-Android_VideoQuit(_THIS)
+void Android_VideoQuit(_THIS)
 {
     Android_QuitMouse();
     Android_QuitTouch();
 }
 
-int
-Android_GetDisplayDPI(_THIS, SDL_VideoDisplay *display, float *ddpi, float *hdpi, float *vdpi)
+int Android_GetDisplayDPI(_THIS, SDL_VideoDisplay *display, float *ddpi, float *hdpi, float *vdpi)
 {
     return Android_JNI_GetDisplayDPI(ddpi, hdpi, vdpi);
 }
 
-void
-Android_SetScreenResolution(int surfaceWidth, int surfaceHeight, int deviceWidth, int deviceHeight, float rate)
+void Android_SetScreenResolution(int surfaceWidth, int surfaceHeight, int deviceWidth, int deviceHeight, float rate)
 {
-    Android_SurfaceWidth  = surfaceWidth;
+    Android_SurfaceWidth = surfaceWidth;
     Android_SurfaceHeight = surfaceHeight;
-    Android_DeviceWidth   = deviceWidth;
-    Android_DeviceHeight  = deviceHeight;
-    Android_ScreenRate    = (int)rate;
+    Android_DeviceWidth = deviceWidth;
+    Android_DeviceHeight = deviceHeight;
+    Android_ScreenRate = (int)rate;
 }
 
-static
-Uint32 format_to_pixelFormat(int format) {
+static Uint32 format_to_pixelFormat(int format)
+{
     Uint32 pf;
-    if (format == AHARDWAREBUFFER_FORMAT_R8G8B8A8_UNORM) {  /* 1 */
+    if (format == AHARDWAREBUFFER_FORMAT_R8G8B8A8_UNORM) { /* 1 */
         pf = SDL_PIXELFORMAT_RGBA8888;
     } else if (format == AHARDWAREBUFFER_FORMAT_R8G8B8X8_UNORM) { /* 2 */
         pf = SDL_PIXELFORMAT_RGBX8888;
@@ -258,8 +249,7 @@ Uint32 format_to_pixelFormat(int format) {
     return pf;
 }
 
-void
-Android_SetFormat(int format_wanted, int format_got)
+void Android_SetFormat(int format_wanted, int format_got)
 {
     Uint32 pf_wanted;
     Uint32 pf_got;
@@ -283,24 +273,23 @@ void Android_SendResize(SDL_Window *window)
       which can happen after VideoInit().
     */
     SDL_VideoDevice *device = SDL_GetVideoDevice();
-    if (device && device->num_displays > 0)
-    {
-        SDL_VideoDisplay *display          = &device->displays[0];
-        display->desktop_mode.format       = Android_ScreenFormat;
-        display->desktop_mode.w            = Android_DeviceWidth;
-        display->desktop_mode.h            = Android_DeviceHeight;
+    if (device && device->num_displays > 0) {
+        SDL_VideoDisplay *display = &device->displays[0];
+        display->desktop_mode.format = Android_ScreenFormat;
+        display->desktop_mode.w = Android_DeviceWidth;
+        display->desktop_mode.h = Android_DeviceHeight;
         display->desktop_mode.refresh_rate = Android_ScreenRate;
     }
 
     if (window) {
         /* Force the current mode to match the resize otherwise the SDL_WINDOWEVENT_RESTORED event
          * will fall back to the old mode */
-        SDL_VideoDisplay *display              = SDL_GetDisplayForWindow(window);
-        display->display_modes[0].format       = Android_ScreenFormat;
-        display->display_modes[0].w            = Android_DeviceWidth;
-        display->display_modes[0].h            = Android_DeviceHeight;
+        SDL_VideoDisplay *display = SDL_GetDisplayForWindow(window);
+        display->display_modes[0].format = Android_ScreenFormat;
+        display->display_modes[0].w = Android_DeviceWidth;
+        display->display_modes[0].h = Android_DeviceHeight;
         display->display_modes[0].refresh_rate = Android_ScreenRate;
-        display->current_mode                  = display->display_modes[0];
+        display->current_mode = display->display_modes[0];
 
         SDL_SendWindowEvent(window, SDL_WINDOWEVENT_RESIZED, Android_SurfaceWidth, Android_SurfaceHeight);
     }
